
Pywbem - A WBEM client and related utilities, written in pure Python
********************************************************************

Pywbem is a WBEM client and WBEM indication listener and provides related
WBEM client-side functionality. It is written in pure Python and runs on
Python 2 and Python 3.

WBEM is a standardized approach for systems management defined by the
`DMTF <https://www.dmtf.org>`_ that is used in the industry for a wide variety
of systems management tasks. See
`WBEM Standards <https://www.dmtf.org/standards/wbem>`_ for more information.
An important use of this approach is the
`SMI-S <https://www.snia.org/tech_activities/standards/curr_standards/smi>`_
standard defined by `SNIA <https://www.snia.org>`_ for managing storage.

Pywbem is based on the idea that a good WBEM client should be easy to use
and not necessarily require a large amount of programming knowledge. It is
suitable for a large range of tasks from simply poking around to writing web
and GUI applications.

The general web site for all projects of the pywbem family is:
https://pywbem.github.io/.

.. toctree::
   :maxdepth: 2
   :numbered:
   :name: mastertoc

   intro.rst
   concepts.rst
   tutorial.rst
   client.rst
   server.rst
   indication.rst
   subscription.rst
   compiler.rst
   mockwbemserver.rst
   utilities.rst
   development.rst
   appendix.rst
   changes.rst
   genindex.rst
.. The genindex.rst above and corresponding file required to include index
